Learn R Programming

CDM (version 2.4-9)

din.validate.qmatrix: Q-Matrix Validation (Q-Matrix Modification) for Mixed DINA/DINO Model

Description

Q-matrix entries can be modified by the Q-matrix validation method of de la Torre (2008). After estimating a mixed DINA/DINO model using the din function, item parameters and the item discrimination parameters $IDI_j$ are recalculated. Q-matrix rows are determined by maximizing the estimated item discrimination index $IDI_j = 1-s_j -g_j$.

Usage

din.validate.qmatrix(object, digits = 3, print = TRUE)

Arguments

object
Object of class din
digits
Number of digits for rounding the output matrix
print
An optional logical indicating whether the function should print the progress of iteration in the estimation process.

Value

  • A list with following entries:
  • coef.modifiedEstimated parameters by applying Q-matrix modificatioons
  • coef.modified.shortA shorted matrix of coef.modified. Only Q-matrix rows which increase the $IDI$ are displayed.
  • q.matrix.propThe proposed Q-matrix by Q-matrix validation.

References

de la Torre, J. (2008). An empirically based method of Q-matrix validation for the DINA model: Development and applications. Journal of Educational Measurement, 45, 343-362.

See Also

Estimated the mixed DINA/DINO model with din.

Examples

Run this code
#################################################################
# SIMULATED EXAMPLE 1: Detection of a mis-specified Q-matrix
#################################################################
set.seed(679)
# specify true Q-matrix
q.matrix <- matrix( 0 , 12 , 3 )
q.matrix[1:3,1] <- 1
q.matrix[4:6,2] <- 1
q.matrix[7:9,3] <- 1
q.matrix[10,] <- c(1,1,0)
q.matrix[11,] <- c(1,0,1)
q.matrix[12,] <- c(0,1,1)
# simulate data
dat <- sim.din( N=4000 , q.matrix)$dat
# incorrectly modify Q-matrix rows 1 and 10
Q1 <- q.matrix
Q1[1,] <- c(1,1,0)
Q1[10,] <- c(1,0,0)
# estimate DINA model
mod <- din( dat , q.matr = Q1, rule = "DINA")
# apply Q-matrix validation
res <- din.validate.qmatrix( mod )

Run the code above in your browser using DataLab